@@ -26,6 +26,7 @@ from calculate.core.datavars import DataVarsCore
 from calculate.core.client.function import clear
 from calculate.consolegui.application.client_class import (
     HTTPSClientCertTransport)
+from calculate.lib.utils.dbus_tools import get_dbus_hostname
 from functools import partial
 from os import path
 from M2Crypto import X509
@@ -51,7 +52,7 @@ def get_cert_groups(cert_file):
         return ""
 
 
-def get_certifactions_for_host(host):
+def get_certifactions_for_host(host, use_dbus=False):
     """
     Получить список сертификатов подходящих для host
     :param host:
@@ -71,18 +72,21 @@ def get_certifactions_for_host(host):
     url = "https://%s:%d/?wsdl" % (host, port)
 
     clear()
-    try:
-        client = Client_suds(url, transport=HTTPSClientCertTransport(
-            None, None, path_to_cert, None))
-        client.wsdl.services[0].setlocation(url)
-        server_host_name = client.service.get_server_host_name()
-        del client
-    except (urllib2.URLError, TransportError) as e:
-        log.debug(_('Failed to connect', ) + _(': ') + str(e))
-        return []
-    except KeyboardInterrupt:
-        log.debug(_("Manually interrupted"))
-        return []
+    if not use_dbus:
+        try:
+            client = Client_suds(url, transport=HTTPSClientCertTransport(
+                None, None, path_to_cert, None))
+            client.wsdl.services[0].setlocation(url)
+            server_host_name = client.service.get_server_host_name()
+            del client
+        except (urllib2.URLError, TransportError) as e:
+            log.debug(_('Failed to connect', ) + _(': ') + str(e))
+            return []
+        except KeyboardInterrupt:
+            log.debug(_("Manually interrupted"))
+            return []
+    else:
+        server_host_name = get_dbus_hostname() or "localhost"
     try:
         import glob
 
@@ -109,11 +113,11 @@ def get_certifactions_for_host(host):
     return []
 
 
-def user_can_run_update():
+def user_can_run_update(use_dbus):
     """
     Текущий пользователь может запускать обновление системы
     """
-    for cert in get_certifactions_for_host("localhost"):
+    for cert in get_certifactions_for_host("localhost", use_dbus=use_dbus):
         groups = get_cert_groups(cert)
         if any(x in groups for x in ("all", "update")):
             return True
