@@ -267,6 +267,8 @@ def get_method_argparser(view, args, cl_core=False):
                                 _("'list' for displaying possible values"))
                 if "boolauto" in field.type:
                     data['metavar'] = "ON/OFF/AUTO"
+                elif "bool3" in field.type:
+                    data['metavar'] = "ON/OFF/AUTO"
                 elif "bool" in field.type:
                     data['metavar'] = "ON/OFF"
                 try:
@@ -514,19 +516,22 @@ def collect_object(client, param_object, view, args, wait_thread=None,
             #if field.uncompatible:
             #    continue
             if (field.element in ['check', 'check_tristate'] and
-                        field.type in ('bool', 'boolauto')) or (
+                        field.type in ('bool', 'boolauto', 'bool3')) or (
                             field.element == 'radio' and field.type == 'bool'):
                 value = _getattr(args, field.name)
-                if value:
-                    if _getattr(args, field.name).lower() in ['on', 'yes']:
-                        value = True
-                    elif _getattr(args,
-                                  field.name).lower() in ['off', 'no']:
-                        value = False
+                if field.type == 'bool3':
+                    pass
+                else:
+                    if value:
+                        if _getattr(args, field.name).lower() in ['on', 'yes']:
+                            value = True
+                        elif _getattr(args,
+                                      field.name).lower() in ['off', 'no']:
+                            value = False
+                        else:
+                            value = None
                     else:
                         value = None
-                else:
-                    value = None
                 param_object = set_obj_item(client, param_object,
                                             field.name, value)
             elif (field.element == 'input' and
