@@ -18,7 +18,7 @@ import os
 import sys
 
 from calculate.lib.cl_lang import setLocalTranslate
-from calculate.lib.utils.files import pathJoin, listDirectory
+from calculate.lib.utils.files import pathJoin, listDirectory, readFile
 from calculate.core.server.loaded_methods import LoadedMethods
 from calculate.core.server.func import uniq
 
@@ -113,7 +113,7 @@ class VariableClCertPerms(Variable):
 
         else:
             if not os.path.exists(group_rights):
-                open(group_rights, 'w')
+                return ["No Methods"]
             with open(group_rights) as fd:
                 t = fd.read()
                 for line in t.splitlines():
@@ -131,22 +131,21 @@ class VariableClCertPerms(Variable):
             add_list_rights = []
             del_list_rights = []
 
-            with open(rights) as fr:
-                t = fr.read()
-                for line in t.splitlines():
-                    words = line.split()
-                    meth = words[0]
-                    for word in words:
-                        try:
-                            word = int(word)
-                        except ValueError:
-                            continue
-                        # compare with certificat number
-                        if cert_id == word:
-                            # if has right
-                            add_list_rights.append(meth)
-                        if cert_id == -word:
-                            del_list_rights.append(meth)
+            t = readFile(rights)
+            for line in t.splitlines():
+                words = line.split()
+                meth = words[0]
+                for word in words:
+                    try:
+                        word = int(word)
+                    except ValueError:
+                        continue
+                    # compare with certificat number
+                    if cert_id == word:
+                        # if has right
+                        add_list_rights.append(meth)
+                    if cert_id == -word:
+                        del_list_rights.append(meth)
 
             results += add_list_rights
             results = uniq(results)
